@@ -7,8 +7,9 @@ import tmp117
 
 i2c = board.I2C()  # uses board.SCL and board.SDA
 # i2c = board.STEMMA_I2C()  # For using the built-in STEMMA QT connector on a microcontroller
-tmp117 = tmp117.TMP117(i2c)
+tmp = tmp117.TMP117(i2c)
 
 while True:
-    print("Temperature: %.2f degrees C" % tmp117.temperature)
+    print(f"Temperature: {tmp.temperature:.2f}°C")
+    print()
     time.sleep(1)
